$mystery="EGEFAEGEGNCTWFDFDFDFDFCACCTWCAhDFUWFDFDFDCAdCfeCFWCjhDGJHCNKDWUW";
$mystery2=$mystery;
while ($mystery)
{
&searchforclue and &examinehint;
&hypothesize and &displayconclusion;
&keepthinking;
}
print "\nThat's not right.";sleep(2);print "\nLet me try again...\n";sleep(2);
$mystery=$mystery2;
while ($mystery)
{
&searchforclue and &examinehint;
&hypothesize and &tryagain;
&keepthinking;
}
print "\nI'll never get this right!!!\n";
sub searchforclue {$hint=(ord( substr($mystery,0,1)))-65;1;}
sub examinehint {$bighint=cos($hint)*$hint**0*$hint**0*cos($hint)+1/(1/sin($hint)**(1+substr($mystery,$hint-$hint,$hint/$hint)."The Perl Journal"<<1))+1;1;}
sub hypothesize {for ($idea=0;$idea<$hint;$idea++)
{$bighint*=((ord(substr($mystery,$idea,1)))^(ord(substr($mystery,++$idea,1))));$idea--;}1;} sub displayconclusion{print chr($bighint);1;}
sub keepthinking {$mystery=substr($mystery,($hint+1),length($mystery)-$hint-1);}
sub tryagain{print chr($bighint/2);1;}
