#!/usr/bin/perl

require 5.005;
use re qw(eval);

@a=map(/$_/, "SHJUBPAYKXZ[KoMnM]JRPC=
KDCAICJFAEHLJGBFM [#
]+ aehJlnoPrTu
sdtcifym-pDSOUJw|^(?:[^%](?{
\$^A.=substr(\$_,ord(substr(\$_,\$a++))-18,1);
})){41}(?{eval substr(\$^A,0,24,'')})")

