#!/usr/bin/perl

require 5.005;
use re qw(eval);

${map(/$_/ && eval || write, "SHJUBPAYKXZ[KmMlM=
KDCAICJFAEHLJGBFMIFCBNCAOHAGHPANWCQRSTABGTAQHUUBGOVFRGCAHWPRHGNM [#
]+ aehJlnoPrTu
sdtcifym-pDSOU|^(?:[^%](?{
\$^A.=substr(\$_,ord(substr(\$_,\$a++))+24,1)
})){${@ARGV?\83:\36}}(?{\$_=substr(\$^A,0,\@ARGV?36:19,'')})")};

