  $a="LANRUOJ LREP EHT";$/=$\;open(X,$0);while(<X>){;s{. 
#'\>$wSuTez=GP/0@?QB$8elqfb`k#'j+qfufqpf#6;--212*x'q>`kq+'j*8
  }{chr(~ord($&)&3|ord($&)&252)}gex;eval $_;} 
#px_R'q_F~x+$                                                                                                                    (2(189(0(6.1???-=>/1-2(:B0-1(5(78@9C<FA??A98NK99>9ED?@HW9GC??<7DFVZ<JLPGG.]X<RcU2^,aM\gOL8>I[dkSIjiQOhoJ`nm?lYs9rfqHpb_K=v2M/t{E$
#>}#,+--*,d*X'j^~df~
#p,_g,$#${'%,fd8         XXXXX X  X XXXX   XXXX  XXXX XXX  X         X  XX  X  X XXX  X   X  XX  X   
#p,+X(-_,/.^*              X   X  X X      X   X X    X  X X         X X  X X  X X  X XX  X X  X X   
#,$ ${+lqg+'2*.71*,df{8    X   XXXX XXX    XXXX  XXX  XXX  X         X X  X X  X XXX  X X X XXXX X   
#sqjmw#iljm+!_m!/#,+       X   X  X X      X     X    X X  X      X  X X  X X  X X X  X  XX X  X X   
#-x45~*,d{*/!_m!8          X   X  X XXXX   X     XXXX X  X XXXX   XXXX  XX   XX  X  X X   X X  X XXXX
